@@ -233,17 +233,14 @@ sub _ep_examples_pop3client_reply {
 sub _format_HNBSP {
     my $self = shift;  my $str = shift;
     return '&nbsp;' if !defined($str) || $str eq '';
-    $str =~ s/([<&>"\$])/$HTML::Entities::char2entity{$1}/g;
-    $str;
+    $self->escapeHTML($str);
 }
 
 sub _format_BR {
     my $self = shift;  my $str = shift;
     return '' unless defined($str);
     join("<BR>\n",
-	 map {
-	       $_ =~ s/([<&>"])/$HTML::Entities::char2entity{$1}/g;
-	       $_ } split(/\r?\n/s, $str));
+	 map { $self->escapeHTML($_) } split(/\r?\n/s, $str));
 }
 
 1;
